@@ -13,30 +13,21 @@ my $zip = Archive::Zip->new();
 die "can't read $zipName\n" unless $zip->read($zipName) == AZ_OK;
 
 # Update the zip
-foreach my $file (@fileNames)
-{
-	$zip->removeMember($file);
-	if ( -r $file )
-	{
-		if ( -f $file )
-		{
-			$zip->addFile($file) or die "Can't add $file to zip!\n";
-		}
-		elsif ( -d $file )
-		{
-			$zip->addDirectory($file) or die "Can't add $file to zip!\n";
-		}
-		else
-		{
-			warn "Don't know how to add $file\n";
-		}
-	}
-	else
-	{
-		warn "Can't read $file\n";
-	}
+foreach my $file (@fileNames) {
+    $zip->removeMember($file);
+    if (-r $file) {
+        if (-f $file) {
+            $zip->addFile($file) or die "Can't add $file to zip!\n";
+        } elsif (-d $file) {
+            $zip->addDirectory($file) or die "Can't add $file to zip!\n";
+        } else {
+            warn "Don't know how to add $file\n";
+        }
+    } else {
+        warn "Can't read $file\n";
+    }
 }
 
 # Now the zip is updated. Write it back via a temp file.
 
-exit( $zip->overwrite() );
+exit($zip->overwrite());
